@@ -33,6 +33,292 @@ from apivideo.model.not_found import NotFound
 
 class ChaptersApi(_EndPoint):
 
+    def upload(
+            self,
+            video_id,
+            language,
+            file,
+            **kwargs
+        ):
+            """Upload a chapter  # noqa: E501
+
+            Upload a VTT file to add chapters to your video. Chapters help break the video into sections. Read our [tutorial](https://api.video/blog/tutorials/adding-chapters-to-your-videos) for more details.  # noqa: E501
+            This method makes a synchronous HTTP request by default. To make an
+            asynchronous HTTP request, please pass async_req=True
+
+            >>> thread = api.upload(video_id, language, file, async_req=True)
+            >>> result = thread.get()
+
+            Args:
+                video_id (str): The unique identifier for the video you want to upload a chapter for.
+                language (str): A valid [BCP 47](https://github.com/libyal/libfwnt/wiki/Language-Code-identifiers) language representation.
+                file (file_type): The VTT file describing the chapters you want to upload.
+
+            Keyword Args:
+                _return_http_data_only (bool): response data without head status
+                    code and headers. Default is True.
+                _preload_content (bool): if False, the urllib3.HTTPResponse object
+                    will be returned without reading/decoding response data.
+                    Default is True.
+                _request_timeout (float/tuple): timeout setting for this request. If one
+                    number provided, it will be total request timeout. It can also
+                    be a pair (tuple) of (connection, read) timeouts.
+                    Default is None.
+                async_req (bool): execute request asynchronously
+
+            Returns:
+                Chapter
+                    If the method is called asynchronously, returns the request
+                    thread.
+            """
+            kwargs['async_req'] = kwargs.get(
+                'async_req', False
+            )
+            kwargs['_return_http_data_only'] = kwargs.get(
+                '_return_http_data_only', True
+            )
+            kwargs['_preload_content'] = kwargs.get(
+                '_preload_content', True
+            )
+            kwargs['_request_timeout'] = kwargs.get(
+                '_request_timeout', None
+            )
+            kwargs['video_id'] = \
+                video_id
+            kwargs['language'] = \
+                language
+            kwargs['file'] = \
+                file
+
+            params_map = {
+                'all': [
+                    'video_id',
+                    'language',
+                    'file',
+                    'async_req',
+                    '_preload_content',
+                    '_request_timeout',
+                    '_return_http_data_only'
+                ],
+                'required': [
+                    'video_id',
+                    'language',
+                    'file',
+                ],
+                'nullable': [
+                    '_request_timeout'
+                ],
+                'enum': [
+                ],
+                'validation': [
+                ]
+            }
+            validations = {
+            }
+            allowed_values = {
+            }
+            openapi_types = {
+                'video_id':
+                    (str,),
+                'language':
+                    (str,),
+                'file':
+                    (file_type,),
+                'async_req': (bool,),
+                '_preload_content': (bool,),
+                '_request_timeout': (none_type, int, (int,), [int]),
+                '_return_http_data_only': (bool,)
+            }
+            attribute_map = {
+                'video_id': 'videoId',
+                'language': 'language',
+                'file': 'file',
+            }
+            location_map = {
+                'video_id': 'path',
+                'language': 'path',
+                'file': 'form',
+            }
+            collection_format_map = {
+            }
+
+            for key, value in kwargs.items():
+                if key not in params_map['all']:
+                    raise ApiTypeError(
+                        "Got an unexpected parameter '%s'"
+                        " to method `upload`" %
+                        (key, )
+                    )
+                if (key not in params_map['nullable'] and value is None):
+                    raise ApiValueError(
+                        "Value may not be None for non-nullable parameter `%s`"
+                        " when calling `upload`" %
+                        (key, )
+                    )
+
+            for key in params_map['required']:
+                if key not in kwargs.keys():
+                    raise ApiValueError(
+                        "Missing the required parameter `%s` when calling "
+                        "`upload`" % (key, )
+                    )
+
+            self._validate_inputs(kwargs, params_map, allowed_values, validations, openapi_types)
+            params = self._gather_params(kwargs, location_map, attribute_map, openapi_types, collection_format_map)
+            return self.api_client.call_api(
+                "/videos/{videoId}/chapters/{language}",
+                "POST",
+                params['path'],
+                params['query'],
+                params['header'],
+                body=params['body'],
+                post_params=params['form'],
+                files=params['file'],
+                response_type=(Chapter,),
+                async_req=kwargs['async_req'],
+                _return_http_data_only=kwargs['_return_http_data_only'],
+                _preload_content=kwargs['_preload_content'],
+                _request_timeout=kwargs['_request_timeout'],
+                collection_formats=params['collection_format'])
+
+    def get(
+            self,
+            video_id,
+            language,
+            **kwargs
+        ):
+            """Retrieve a chapter  # noqa: E501
+
+            Retrieve a chapter for a video in a specific language.  Chapters help your viewers find the sections of the video they are most interested in viewing. Tutorials that use the [chapters endpoint](https://api.video/blog/endpoints/chapters).  # noqa: E501
+            This method makes a synchronous HTTP request by default. To make an
+            asynchronous HTTP request, please pass async_req=True
+
+            >>> thread = api.get(video_id, language, async_req=True)
+            >>> result = thread.get()
+
+            Args:
+                video_id (str): The unique identifier for the video you want to show a chapter for.
+                language (str): A valid [BCP 47](https://github.com/libyal/libfwnt/wiki/Language-Code-identifiers) language representation.
+
+            Keyword Args:
+                _return_http_data_only (bool): response data without head status
+                    code and headers. Default is True.
+                _preload_content (bool): if False, the urllib3.HTTPResponse object
+                    will be returned without reading/decoding response data.
+                    Default is True.
+                _request_timeout (float/tuple): timeout setting for this request. If one
+                    number provided, it will be total request timeout. It can also
+                    be a pair (tuple) of (connection, read) timeouts.
+                    Default is None.
+                async_req (bool): execute request asynchronously
+
+            Returns:
+                Chapter
+                    If the method is called asynchronously, returns the request
+                    thread.
+            """
+            kwargs['async_req'] = kwargs.get(
+                'async_req', False
+            )
+            kwargs['_return_http_data_only'] = kwargs.get(
+                '_return_http_data_only', True
+            )
+            kwargs['_preload_content'] = kwargs.get(
+                '_preload_content', True
+            )
+            kwargs['_request_timeout'] = kwargs.get(
+                '_request_timeout', None
+            )
+            kwargs['video_id'] = \
+                video_id
+            kwargs['language'] = \
+                language
+
+            params_map = {
+                'all': [
+                    'video_id',
+                    'language',
+                    'async_req',
+                    '_preload_content',
+                    '_request_timeout',
+                    '_return_http_data_only'
+                ],
+                'required': [
+                    'video_id',
+                    'language',
+                ],
+                'nullable': [
+                    '_request_timeout'
+                ],
+                'enum': [
+                ],
+                'validation': [
+                ]
+            }
+            validations = {
+            }
+            allowed_values = {
+            }
+            openapi_types = {
+                'video_id':
+                    (str,),
+                'language':
+                    (str,),
+                'async_req': (bool,),
+                '_preload_content': (bool,),
+                '_request_timeout': (none_type, int, (int,), [int]),
+                '_return_http_data_only': (bool,)
+            }
+            attribute_map = {
+                'video_id': 'videoId',
+                'language': 'language',
+            }
+            location_map = {
+                'video_id': 'path',
+                'language': 'path',
+            }
+            collection_format_map = {
+            }
+
+            for key, value in kwargs.items():
+                if key not in params_map['all']:
+                    raise ApiTypeError(
+                        "Got an unexpected parameter '%s'"
+                        " to method `get`" %
+                        (key, )
+                    )
+                if (key not in params_map['nullable'] and value is None):
+                    raise ApiValueError(
+                        "Value may not be None for non-nullable parameter `%s`"
+                        " when calling `get`" %
+                        (key, )
+                    )
+
+            for key in params_map['required']:
+                if key not in kwargs.keys():
+                    raise ApiValueError(
+                        "Missing the required parameter `%s` when calling "
+                        "`get`" % (key, )
+                    )
+
+            self._validate_inputs(kwargs, params_map, allowed_values, validations, openapi_types)
+            params = self._gather_params(kwargs, location_map, attribute_map, openapi_types, collection_format_map)
+            return self.api_client.call_api(
+                "/videos/{videoId}/chapters/{language}",
+                "GET",
+                params['path'],
+                params['query'],
+                params['header'],
+                body=params['body'],
+                post_params=params['form'],
+                files=params['file'],
+                response_type=(Chapter,),
+                async_req=kwargs['async_req'],
+                _return_http_data_only=kwargs['_return_http_data_only'],
+                _preload_content=kwargs['_preload_content'],
+                _request_timeout=kwargs['_request_timeout'],
+                collection_formats=params['collection_format'])
+
     def delete(
             self,
             video_id,
@@ -41,6 +327,7 @@ class ChaptersApi(_EndPoint):
         ):
             """Delete a chapter  # noqa: E501
 
+            Delete a chapter in a specific language by providing the video ID for the video you want to delete the chapter from and the language the chapter is in.  # noqa: E501
             This method makes a synchronous HTTP request by default. To make an
             asynchronous HTTP request, please pass async_req=True
 
@@ -310,289 +597,3 @@ class ChaptersApi(_EndPoint):
                 _request_timeout=kwargs['_request_timeout'],
                 collection_formats=params['collection_format'])
 
-    def get(
-            self,
-            video_id,
-            language,
-            **kwargs
-        ):
-            """Show a chapter  # noqa: E501
-
-            Chapters help your viewers find the sections of the video they are most interested in viewing. Tutorials that use the [chapters endpoint](https://api.video/blog/endpoints/chapters).  # noqa: E501
-            This method makes a synchronous HTTP request by default. To make an
-            asynchronous HTTP request, please pass async_req=True
-
-            >>> thread = api.get(video_id, language, async_req=True)
-            >>> result = thread.get()
-
-            Args:
-                video_id (str): The unique identifier for the video you want to show a chapter for.
-                language (str): A valid [BCP 47](https://github.com/libyal/libfwnt/wiki/Language-Code-identifiers) language representation.
-
-            Keyword Args:
-                _return_http_data_only (bool): response data without head status
-                    code and headers. Default is True.
-                _preload_content (bool): if False, the urllib3.HTTPResponse object
-                    will be returned without reading/decoding response data.
-                    Default is True.
-                _request_timeout (float/tuple): timeout setting for this request. If one
-                    number provided, it will be total request timeout. It can also
-                    be a pair (tuple) of (connection, read) timeouts.
-                    Default is None.
-                async_req (bool): execute request asynchronously
-
-            Returns:
-                Chapter
-                    If the method is called asynchronously, returns the request
-                    thread.
-            """
-            kwargs['async_req'] = kwargs.get(
-                'async_req', False
-            )
-            kwargs['_return_http_data_only'] = kwargs.get(
-                '_return_http_data_only', True
-            )
-            kwargs['_preload_content'] = kwargs.get(
-                '_preload_content', True
-            )
-            kwargs['_request_timeout'] = kwargs.get(
-                '_request_timeout', None
-            )
-            kwargs['video_id'] = \
-                video_id
-            kwargs['language'] = \
-                language
-
-            params_map = {
-                'all': [
-                    'video_id',
-                    'language',
-                    'async_req',
-                    '_preload_content',
-                    '_request_timeout',
-                    '_return_http_data_only'
-                ],
-                'required': [
-                    'video_id',
-                    'language',
-                ],
-                'nullable': [
-                    '_request_timeout'
-                ],
-                'enum': [
-                ],
-                'validation': [
-                ]
-            }
-            validations = {
-            }
-            allowed_values = {
-            }
-            openapi_types = {
-                'video_id':
-                    (str,),
-                'language':
-                    (str,),
-                'async_req': (bool,),
-                '_preload_content': (bool,),
-                '_request_timeout': (none_type, int, (int,), [int]),
-                '_return_http_data_only': (bool,)
-            }
-            attribute_map = {
-                'video_id': 'videoId',
-                'language': 'language',
-            }
-            location_map = {
-                'video_id': 'path',
-                'language': 'path',
-            }
-            collection_format_map = {
-            }
-
-            for key, value in kwargs.items():
-                if key not in params_map['all']:
-                    raise ApiTypeError(
-                        "Got an unexpected parameter '%s'"
-                        " to method `get`" %
-                        (key, )
-                    )
-                if (key not in params_map['nullable'] and value is None):
-                    raise ApiValueError(
-                        "Value may not be None for non-nullable parameter `%s`"
-                        " when calling `get`" %
-                        (key, )
-                    )
-
-            for key in params_map['required']:
-                if key not in kwargs.keys():
-                    raise ApiValueError(
-                        "Missing the required parameter `%s` when calling "
-                        "`get`" % (key, )
-                    )
-
-            self._validate_inputs(kwargs, params_map, allowed_values, validations, openapi_types)
-            params = self._gather_params(kwargs, location_map, attribute_map, openapi_types, collection_format_map)
-            return self.api_client.call_api(
-                "/videos/{videoId}/chapters/{language}",
-                "GET",
-                params['path'],
-                params['query'],
-                params['header'],
-                body=params['body'],
-                post_params=params['form'],
-                files=params['file'],
-                response_type=(Chapter,),
-                async_req=kwargs['async_req'],
-                _return_http_data_only=kwargs['_return_http_data_only'],
-                _preload_content=kwargs['_preload_content'],
-                _request_timeout=kwargs['_request_timeout'],
-                collection_formats=params['collection_format'])
-
-    def upload(
-            self,
-            video_id,
-            language,
-            file,
-            **kwargs
-        ):
-            """Upload a chapter  # noqa: E501
-
-            Chapters help break the video into sections. Read our [tutorial](https://api.video/blog/tutorials/adding-chapters-to-your-videos) for more details.  # noqa: E501
-            This method makes a synchronous HTTP request by default. To make an
-            asynchronous HTTP request, please pass async_req=True
-
-            >>> thread = api.upload(video_id, language, file, async_req=True)
-            >>> result = thread.get()
-
-            Args:
-                video_id (str): The unique identifier for the video you want to upload a chapter for.
-                language (str): A valid [BCP 47](https://github.com/libyal/libfwnt/wiki/Language-Code-identifiers) language representation.
-                file (file_type): The VTT file describing the chapters you want to upload.
-
-            Keyword Args:
-                _return_http_data_only (bool): response data without head status
-                    code and headers. Default is True.
-                _preload_content (bool): if False, the urllib3.HTTPResponse object
-                    will be returned without reading/decoding response data.
-                    Default is True.
-                _request_timeout (float/tuple): timeout setting for this request. If one
-                    number provided, it will be total request timeout. It can also
-                    be a pair (tuple) of (connection, read) timeouts.
-                    Default is None.
-                async_req (bool): execute request asynchronously
-
-            Returns:
-                Chapter
-                    If the method is called asynchronously, returns the request
-                    thread.
-            """
-            kwargs['async_req'] = kwargs.get(
-                'async_req', False
-            )
-            kwargs['_return_http_data_only'] = kwargs.get(
-                '_return_http_data_only', True
-            )
-            kwargs['_preload_content'] = kwargs.get(
-                '_preload_content', True
-            )
-            kwargs['_request_timeout'] = kwargs.get(
-                '_request_timeout', None
-            )
-            kwargs['video_id'] = \
-                video_id
-            kwargs['language'] = \
-                language
-            kwargs['file'] = \
-                file
-
-            params_map = {
-                'all': [
-                    'video_id',
-                    'language',
-                    'file',
-                    'async_req',
-                    '_preload_content',
-                    '_request_timeout',
-                    '_return_http_data_only'
-                ],
-                'required': [
-                    'video_id',
-                    'language',
-                    'file',
-                ],
-                'nullable': [
-                    '_request_timeout'
-                ],
-                'enum': [
-                ],
-                'validation': [
-                ]
-            }
-            validations = {
-            }
-            allowed_values = {
-            }
-            openapi_types = {
-                'video_id':
-                    (str,),
-                'language':
-                    (str,),
-                'file':
-                    (file_type,),
-                'async_req': (bool,),
-                '_preload_content': (bool,),
-                '_request_timeout': (none_type, int, (int,), [int]),
-                '_return_http_data_only': (bool,)
-            }
-            attribute_map = {
-                'video_id': 'videoId',
-                'language': 'language',
-                'file': 'file',
-            }
-            location_map = {
-                'video_id': 'path',
-                'language': 'path',
-                'file': 'form',
-            }
-            collection_format_map = {
-            }
-
-            for key, value in kwargs.items():
-                if key not in params_map['all']:
-                    raise ApiTypeError(
-                        "Got an unexpected parameter '%s'"
-                        " to method `upload`" %
-                        (key, )
-                    )
-                if (key not in params_map['nullable'] and value is None):
-                    raise ApiValueError(
-                        "Value may not be None for non-nullable parameter `%s`"
-                        " when calling `upload`" %
-                        (key, )
-                    )
-
-            for key in params_map['required']:
-                if key not in kwargs.keys():
-                    raise ApiValueError(
-                        "Missing the required parameter `%s` when calling "
-                        "`upload`" % (key, )
-                    )
-
-            self._validate_inputs(kwargs, params_map, allowed_values, validations, openapi_types)
-            params = self._gather_params(kwargs, location_map, attribute_map, openapi_types, collection_format_map)
-            return self.api_client.call_api(
-                "/videos/{videoId}/chapters/{language}",
-                "POST",
-                params['path'],
-                params['query'],
-                params['header'],
-                body=params['body'],
-                post_params=params['form'],
-                files=params['file'],
-                response_type=(Chapter,),
-                async_req=kwargs['async_req'],
-                _return_http_data_only=kwargs['_return_http_data_only'],
-                _preload_content=kwargs['_preload_content'],
-                _request_timeout=kwargs['_request_timeout'],
-                collection_formats=params['collection_format'])
-
